==> shaonutil-0.0.0.22.1.tar.gz: shaonutil-0.0.0.22.1/shaonutil/image.py <==
"""Image"""
from PIL import Image,ImageDraw,ImageFont,ImageOps

def change_image_size_ratio(img_name,out_name,percent):
	im = Image.open(img_name)
	width, height = im.size
	Iwidth, Iheight = int(width + width*(percent/100)) , int(height + height*(percent/100))
	im = im.resize((Iwidth, Iheight), resample=Image.ANTIALIAS)
	im.save(out_name)

def draw_text(img,text,fnt_name,fnt_size):
	d = ImageDraw.Draw(img)
	fnt = ImageFont.truetype(fnt_name, fnt_size)
	d.text((0,0), text, font=fnt, fill=(0,0,0))
	del d
	return img

def merge_horizontally(images):
	widths, heights = zip(*(i.size for i in images))

	total_width = sum(widths)
	max_height = max(heights)

	new_im = Image.new('RGB', (total_width, max_height))

	x_offset = 0
	for im in images:
		new_im.paste(im, (x_offset,0))
		x_offset += im.size[0]

	return new_im

def merge_vertically(images):
	widths, heights = zip(*(i.size for i in images))

	max_width = max(widths)
	total_height = sum(heights)

	new_im = Image.new('RGB', (max_width, total_height))

	y_offset = 0
	for im in images:
		new_im.paste(im, (0,y_offset))
		y_offset += im.size[1]

	return new_im


def give_screenshot_caption(img_name,text,fnt_path):
	img1 = Image.open(img_name)

	width,height = img1.size
	x0,y0=0,0
	x1=width
	y1=height*(5/100)
	fnt_size = int(y1)

	#img_with_border = ImageOps.expand(img1,border=fnt_size,fill='blue')
	new_im = Image.new('RGB', (width, fnt_size), (0,0,255))
	img_text = draw_text(new_im,text,fnt_path,fnt_size)
	
	img__ = merge_vertically([img_text,img1])
	img__.save(img_name, "PNG", quality=75)

if __name__ == '__main__':
	pass

==> shaonutil-0.0.0.59.1.tar.gz: shaonutil-0.0.0.59.1/shaonutil/image.py <==
"""Image"""
from PIL import Image,ImageDraw,ImageFont,ImageOps
from svglib.svglib import svg2rlg
from reportlab.graphics import renderPDF, renderPM

def svg2img(infile,outfile):
	drawing = svg2rlg(infile)
	ext = outfile.split('.')[-1]
	renderPM.drawToFile(drawing, outfile, fmt=ext.upper())

def svg2pdf(infile,outfile):
	drawing = svg2rlg(infile)
	renderPDF.drawToFile(drawing, outfile)

def change_image_size_ratio(img_name,out_name,percent):
	im = Image.open(img_name)
	width, height = im.size
	Iwidth, Iheight = int(width + width*(percent/100)) , int(height + height*(percent/100))
	im = im.resize((Iwidth, Iheight), resample=Image.ANTIALIAS)
	im.save(out_name)

def draw_text(img,text,fnt_name,fnt_size):
	d = ImageDraw.Draw(img)
	fnt = ImageFont.truetype(fnt_name, fnt_size)
	d.text((0,0), text, font=fnt, fill=(0,0,0))
	del d
	return img

def merge_horizontally(images,filename=''):
	if type(images[0]) == Image.Image:
		pass
	elif type(images[0]) == str:
		images = [Image.open(x) for x in images]

	widths, heights = zip(*(i.size for i in images))

	total_width = sum(widths)
	max_height = max(heights)

	new_im = Image.new('RGB', (total_width, max_height))

	x_offset = 0
	for im in images:
		new_im.paste(im, (x_offset,0))
		x_offset += im.size[0]

	if len(filename)>0:
		new_im.save(filename)
		return filename
	else:
		return new_im

def merge_vertically(images,filename=''):
	if type(images[0]) == Image.Image:
		pass
	elif type(images[0]) == str:
		images = [Image.open(x) for x in images]

	widths, heights = zip(*(i.size for i in images))

	max_width = max(widths)
	total_height = sum(heights)

	new_im = Image.new('RGB', (max_width, total_height))

	y_offset = 0
	for im in images:
		new_im.paste(im, (0,y_offset))
		y_offset += im.size[1]

	
	if len(filename)>0:
		new_im.save(filename)
		return filename
	else:
		return new_im


def give_screenshot_caption(img_name,text,fnt_path):
	img1 = Image.open(img_name)

	width,height = img1.size
	x0,y0=0,0
	x1=width
	y1=height*(5/100)
	fnt_size = int(y1)

	#img_with_border = ImageOps.expand(img1,border=fnt_size,fill='blue')
	new_im = Image.new('RGB', (width, fnt_size), (0,0,255))
	img_text = draw_text(new_im,text,fnt_path,fnt_size)
	
	img__ = merge_vertically([img_text,img1])
	img__.save(img_name, "PNG", quality=75)

if __name__ == '__main__':
	pass
